recitale
########

More or less a small clone of exposure.co in form of a static website generator. 
For those of you who don't know what exposure.co is, it allows you to tell a story with your pictures.

You can find example usages here:

 * http://surleschemins.fr
 * http://media.faimaison.net/photos/galerie/
 * https://www.thebrownianmovement.org/
 * http://outside.browny.pink
 * http://such.life
 * http://www.street-art.me

Why
===

I wanted to learn a bit of advanced css and I wanted to self-host my data instead of using exposure.co.

Licence
=======

GPLv3+

Origin
======

recitale started as a fork of `prosopopee <https://github.com/Psycojoker/prosopopee>`__.

recitale is a contraction of `tale` and the French word `récit` which are both depicting the same thing: a story.

It is also a play on `recital` which is related to poetry reading.

recitale should be pronounced /ʁe.siˈteɪl/ that is, the French pronounciation for `récit <https://en.wiktionary.org/wiki/r%C3%A9cit#Pronunciation>`__ followed
by the English pronounciation of `tale <https://en.wiktionary.org/wiki/tale#Pronunciation>`__.

Documentation
=============


.. toctree::
   :maxdepth: 2

   install
   configuration
   sections
   example
   build
   theming
   authors
   changelog
